from typing import Any

import pymongo
from fastapi import APIRouter, Depends
from motor.motor_asyncio import AsyncIOMotorDatabase
import crud, schemas

from db import get_database
from api import deps

router = APIRouter()


@router.post("/create")
async def create(
        data_in: schemas.ReportCreate,
        db: AsyncIOMotorDatabase = Depends(get_database),
        current_user: schemas.UserDB = Depends(deps.get_current_user)
) -> schemas.Msg:
    """新建报表"""
    try:
        await crud.report.create(db, data_in, user_id=current_user.id)
    except pymongo.errors.DuplicateKeyError:
        return schemas.Msg(code=-1, msg='error', data='报表已存在')

    return schemas.Msg(code=0, msg='ok', data='创建成功')


@router.post("/read_report")
async def read_report(
        data_in: schemas.ReportRead,
        db: AsyncIOMotorDatabase = Depends(get_database),
        current_user: schemas.UserDB = Depends(deps.get_current_user)
) -> Any:
    """获取已建报表"""

    res = await crud.report.read_report(db, user_id=current_user.id, project_id=data_in.project_id)
    return res


@router.post("/delete")
async def delete(
        data_in: schemas.ReportDelete,
        db: AsyncIOMotorDatabase = Depends(get_database),
        current_user: schemas.UserDB = Depends(deps.get_current_user)
) -> schemas.Msg:
    """删除报表"""
    # 删除Report 自己创建的
    del_report = await crud.report.delete(db, _id=data_in.id, user_id=current_user.id)

    if del_report.deleted_count == 0:
        return schemas.Msg(code=-1, msg='error', data='删除失败')
    return schemas.Msg(code=0, msg='ok', data='删除成功')
